<template>
  <AdminLayout>
    <DashboardHeader>
      <DashboardTitle>{{ $t("app.admin.settings.links.title") }}</DashboardTitle>
    </DashboardHeader>
    <SettingsBody>
      <template v-if="linksSettingsFetch.hasErrors">
        <ErrorState />
      </template>
      <template v-else>
        <FormGroup
          :is-loading="linksSettingsFetch.isFetching"
          @submit="submit"
        >
          <AlertError v-if="form.errors && form.errors?.unknown">
            {{ form.errors.unknown }}
          </AlertError>
          <FormSection>
            <FormInput
              id="homepage"
              :errors="form.errors.homepage"
            >
              <FormSwitch
                v-model="form.values.homepage"
                description="app.admin.settings.links.form.homepage.description"
                label="app.admin.settings.links.form.homepage.label"
                name="homepage"
                required
              />
            </FormInput>
            <FormInput
              id="homepage_expiration"
              :errors="form.errors.homepage_expiration"
            >
              <FormLabel>{{ $t("app.admin.settings.links.form.homepage_expiration.label") }}</FormLabel>
              <FormSelect
                v-model="form.values.homepage_expiration"
                :options="linkExpirations"
                index="value"
                label="label"
                name="homepage_expiration"
                required
              />
            </FormInput>
            <FormInput
              id="default_domain"
              :errors="form.errors.default_domain"
            >
              <FormLabel>{{ $t("app.admin.settings.links.form.default_domain.label") }}</FormLabel>
              <FormSelect
                v-model="form.values.default_domain"
                :options="domains"
                index="id"
                label="domain"
                name="default_domain"
                required
              />
            </FormInput>
            <FormInput
              id="allow_all_domains"
              :errors="form.errors.allow_all_domains"
            >
              <FormSwitch
                v-model="form.values.allow_all_domains"
                description="app.admin.settings.links.form.allow_all_domains.description"
                label="app.admin.settings.links.form.allow_all_domains.label"
                name="allow_all_domains"
                required
              />
            </FormInput>
          </FormSection>
          <div>
            <FormSubmit
              :processing="form.isFetching"
              class="btn btn-black"
            >
              {{ $t("app.admin.settings.submit") }}
            </FormSubmit>
          </div>
        </FormGroup>
      </template>
    </SettingsBody>
  </AdminLayout>
</template>

<script lang="ts" setup>
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import useForm from "@/js/contexts/shared/composables/useForm";
import AdminLayout from "@/js/contexts/admin/shared/ui/layouts/AdminLayout.vue";
import DashboardHeader from "@/js/contexts/shared/ui/components/dashboard/DashboardHeader.vue";
import DashboardTitle from "@/js/contexts/shared/ui/components/dashboard/DashboardTitle.vue";
import SettingsBody from "@/js/contexts/admin/settings/ui/components/SettingsBody.vue";
import ErrorState from "@/js/contexts/shared/ui/components/error/ErrorState.vue";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormSection from "@/js/contexts/form/ui/components/FormSection.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormSwitch from "@/js/contexts/form/ui/components/FormSwitch.vue";
import FormSelect from "@/js/contexts/form/ui/components/FormSelect.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import type { Domain } from "@/js/contexts/shared/models/Domain";

type Response = {
  homepage: boolean;
  homepage_expiration: string;
  default_domain: number | null;
  allow_all_domains: boolean;
};

const { t } = useI18n();
const { successNotification } = useNotification();

useHead({
  title: t("app.admin.settings.links.title"),
});

const domains = ref<Domain[]>([]);
const linkExpirations = computed<{ value: string; label: string }[]>(() => [
  { value: "never", label: t("app.admin.settings.links.form.homepage_expiration.options.never") },
  { value: "one_day", label: t("app.admin.settings.links.form.homepage_expiration.options.one_day") },
  { value: "three_days", label: t("app.admin.settings.links.form.homepage_expiration.options.three_days") },
  { value: "week", label: t("app.admin.settings.links.form.homepage_expiration.options.week") },
  { value: "month", label: t("app.admin.settings.links.form.homepage_expiration.options.month") },
]);

const domainsFetch = useFetch("/api/links/domains");
const linksSettingsFetch = useFetch("/api/admin/settings/links", { isFetching: true });

const form = useForm<{
  homepage: boolean;
  homepage_expiration: string;
  default_domain: number | null;
  allow_all_domains: boolean;
}>({
  homepage: false,
  homepage_expiration: "never",
  default_domain: null,
  allow_all_domains: true,
});

onMounted(() => {
  domainsFetch.get<{ data: Domain[] }>().then((response) => (domains.value = response.data.data));

  linksSettingsFetch.get<Response>().then((response) => {
    form.values.homepage = response.data.homepage;
    form.values.homepage_expiration = response.data.homepage_expiration;
    form.values.default_domain = response.data.default_domain;
    form.values.allow_all_domains = response.data.allow_all_domains;
    form.updatedValues();
  });
});

const submit = () => {
  form.post("/api/admin/settings/links", {
    onSuccess: () => successNotification(t("app.admin.settings.success")),
  });
};
</script>
